@@ -1,7 +1,7 @@
 package Bencher::Formatter::RoundNumbers;
 
-our $DATE = '2016-06-30'; # DATE
-our $VERSION = '1.014'; # VERSION
+our $DATE = '2016-07-12'; # DATE
+our $VERSION = '1.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ sub munge_result {
             if ($rit->{errors} == 0) {
                 6;
             } elsif (exists $rit->{time}) {
-                sprintf("%d", log( $rit->{time} /
+                sprintf("%d", log( abs($rit->{time}) /
                                        ($envres->[3]{'func.time_factor'} // 1) /
                                        $rit->{errors} )/log(10));
             } else {
@@ -85,7 +85,7 @@ Bencher::Formatter::RoundNumbers - Round numbers (rate, time) to certain signifi
 
 =head1 VERSION
 
-This document describes version 1.014 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-06-30.
+This document describes version 1.015 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-07-12.
 
 =for Pod::Coverage .*
 
